Capability

Enum Capability 

pub enum Capability {
    NetemulDevfs(DevfsDep),
    NetemulNetworkContext(Empty),
    LogSink(Empty),
    ChildDep(ChildDep),
    StorageDep(StorageDep),
    TracingProvider(Empty),
}

Variants



NetemulDevfs(DevfsDep)

The devfs instance offered by netemul, where virtual devices are mounted.



NetemulNetworkContext(Empty)

The network context offered by netemul, shared between all the managed realms in a given sandbox.



LogSink(Empty)

The [fuchsia.logger/LogSink] offered by netemul.

Decorates logs produced by components in the managed realm and forwards them to syslog.



ChildDep(ChildDep)

A dependency on a capability exposed by another child component in the same test realm.



StorageDep(StorageDep)

A dependency on a storage capability offered by netemul.



TracingProvider(Empty)

A dependency on the capability to register a tracing provider.

Implementations

Source

impl Capability

pub fn ordinal(&self) -> u64