pub struct SandboxProxy { /* private fields */ }Implementations
Sourceimpl SandboxProxy
impl SandboxProxy
Sourcepub fn take_event_stream(&self) -> SandboxEventStream
pub fn take_event_stream(&self) -> SandboxEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn create_realm(
&self,
realm: ServerEnd<ManagedRealmMarker>,
options: RealmOptions,
) -> Result<(), Error>
pub fn create_realm( &self, realm: ServerEnd<ManagedRealmMarker>, options: RealmOptions, ) -> Result<(), Error>
Creates a new realm configured by options.
- request
realmrequest handle to the newly created managed realm. - request
optionsconfigures the setup and child components ofrealm. Ifoptionsis invalid,realmwill be closed.
Errors are presented as an epitaph on the realm channel.
- error
ZX_ERR_INVALID_ARGSifoptionswas invalid. - error
ZX_ERR_INTERNALfor internal errors, including failures to build the requested component topology.
Sourcepub fn get_network_context(
&self,
network_context: ServerEnd<NetworkContextMarker>,
) -> Result<(), Error>
pub fn get_network_context( &self, network_context: ServerEnd<NetworkContextMarker>, ) -> Result<(), Error>
Gets this sandbox’s network context.
- request
network_contextrequest handle to the network context.